@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Markdown Common Regular Expressions - ~/lib/Regexp/Common/Markdown.pm
-## Version v0.1.3
+## Version v0.1.4
 ## Copyright(c) 2020 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <@sitael.tokyo.deguest.jp>
 ## Created 2020/08/01
-## Modified 2020/08/15
+## Modified 2020/08/16
 ## 
 ##----------------------------------------------------------------------------
 package Regexp::Common::Markdown;
@@ -19,7 +19,7 @@ BEGIN
     ## We use URI::tel instead of Regexp::Common::tel because its regular expression is antiquated
     ## URI::tel uses the latest rfc3966
     use URI::tel;
-    our $VERSION = 'v0.1.3';
+    our $VERSION = 'v0.1.4';
 
     our $SPACE_RE = qr/[[:blank:]\h]/;
     ## Including vertical space like new lines
@@ -602,28 +602,32 @@ $LIST_TYPE_ORDERED
     /xm,
     
     ## https://regexr.com/5929n
-    ## https://regex101.com/r/0B3gR4/2/
+    ## https://regex101.com/r/0B3gR4/3
     paragraph => qr/
         (?<para_all>
-            (?:\n{2,}|^)                # Needs 1 or more new lines or start of string
-            (?<para_prefix>[ ]{0,3})    # Possibly some leading spaces, but less than a tab worth
+            (?:\n{2,}|^)                            # Needs 1 or more new lines or start of string
+            (?<para_prefix>[ ]{0,3})                # Possibly some leading spaces, but less than a tab worth
             (?<para_content>
                 (?:
-                    (?!                 # some line content not starting with those exceptions
+                    (?!                             # some line content not starting with those exceptions
                         [[:blank:]\h]{0,3}
                         (?:
-                            [>*+-=\#]
+                            \*{1}[ \t]+             # a list
                             |
-                            \d+\.
+                            (?:\*(?:[ ]\*){2,})     # a horizontal line
                             |
-                            \`{3,}
+                            [>+-=\#]
+                            |
+                            \d+\.                   # ordered list
+                            |
+                            \`{3,}                  # code block
                         )
                     )
                 )
                 .+
-                (?!\n(?:[=-]+))         # Prevents from catching line followed by header markers
+                (?!\n(?:[=-]+))
                 (?:\n|$)
-            )+                          # Allowing multiple occurrences
+            )+
         )
     /mx
     };
@@ -1169,7 +1173,7 @@ Regexp::Common::Markdown - Markdown Common Regular Expressions
 
 =head1 VERSION
 
-    v0.1.3
+    v0.1.4
 
 =head1 DESCRIPTION
 
@@ -2086,7 +2090,7 @@ For example:
 
 This regular expression would capture the whole block up until "Lorem Ipsum", but will be careful not to catch other markdown element after that. Thus, anything after "Lorem Ipsum" would not be caught because this is a blockquote.
 
-You can see example of this regular expression along with test units here: L<https://regex101.com/r/0B3gR4/2/>
+You can see example of this regular expression along with test units here: L<https://regex101.com/r/0B3gR4/3>
 
 The capture names are:
 
